==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ms-MY/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Sahkan Pemutihan Aset Pukal',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Semak aset untuk penghapusan pukal di bawah. Sebaik sahaja dipadam, aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan mana-mana pengguna yang mereka buat sekarang.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Anda akan hapus: asset_count aset.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Aset Kemas Kini Pukal',
    'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang aset sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Agihkan Kepada',
    'checkout_date'		=> 'Tarikh Checkout',
    'checkin_date'		=> 'Tarikh daftar masuk',
    'checkout_to'		=> 'Agihkan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Cipta Harta',
    'date'				=> 'Tarikh Pembelian',
    'depreciation'	    => 'Susut nilai',
    'depreciates_on'	=> 'Susut Nilai Pada',
    'default_location'	=> 'Lokasi Asal',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tarikh EOL',
    'eol_rate'			=> 'Kadar EOL',
    'expected_checkin'  => 'Tarikh Periksa Yang Diharapkan',
    'expires'			=> 'Luput',
    'fully_depreciated'	=> 'Susut Nilai Penuh',
    'help_checkout'		=> 'Jika anda ingin memberikan aset ini dengan segera, pilih "Sedia Digelar" dari senarai status di atas.',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pengeluar',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Harta',
    'notes'				=> 'Nota',
    'order'				=> 'Nombor Pesanan',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Pengguna dibenarkan untuk memohon harta ini',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Siri',
    'status'			=> 'Status',
    'tag'				=> 'Tag Harta',
    'update'			=> 'Kemaskini Harta',
    'warranty'			=> 'Waranti',
        'warranty_expires'		=> 'Tamat Tempoh Waranti',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ms-MY/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Sahkan Pemutihan Aset Pukal',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Semak aset untuk penghapusan pukal di bawah. Sebaik sahaja dipadam, aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan mana-mana pengguna yang mereka buat sekarang.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Anda akan hapus: asset_count aset.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Aset Kemas Kini Pukal',
    'bulk_update_help'	=> 'Borang ini membolehkan anda mengemas kini berbilang aset sekaligus. Hanya isikan medan yang perlu anda ubah. Mana-mana medan yang dibiarkan kosong akan kekal tidak berubah.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Agihkan Kepada',
    'checkout_date'		=> 'Tarikh Checkout',
    'checkin_date'		=> 'Tarikh daftar masuk',
    'checkout_to'		=> 'Agihkan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Cipta Harta',
    'date'				=> 'Tarikh Pembelian',
    'depreciation'	    => 'Susut nilai',
    'depreciates_on'	=> 'Susut Nilai Pada',
    'default_location'	=> 'Lokasi Asal',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tarikh EOL',
    'eol_rate'			=> 'Kadar EOL',
    'expected_checkin'  => 'Tarikh Periksa Yang Diharapkan',
    'expires'			=> 'Luput',
    'fully_depreciated'	=> 'Susut Nilai Penuh',
    'help_checkout'		=> 'Jika anda ingin memberikan aset ini dengan segera, pilih "Sedia Digelar" dari senarai status di atas.',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Pengeluar',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Harta',
    'notes'				=> 'Nota',
    'order'				=> 'Nombor Pesanan',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Pengguna dibenarkan untuk memohon harta ini',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Pilih Jenis Status',
    'serial'			=> 'Siri',
    'status'			=> 'Status',
    'tag'				=> 'Tag Harta',
    'update'			=> 'Kemaskini Harta',
    'warranty'			=> 'Waranti',
        'warranty_expires'		=> 'Tamat Tempoh Waranti',
    'years'				=> 'tahun',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
